==> jc-1.4.0.tar.gz: soot/baf/internal/BStaticInvokeInst.h <==
// public class soot.baf.internal.BStaticInvokeInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 9eae4bbac6711e7a soot_baf_internal_AbstractInvokeInst
// @dep_class e5868ea131204b74 soot_baf_internal_BStaticInvokeInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInvokeInst

#include "soot/baf/internal/AbstractInvokeInst.h"

#ifndef _JC_soot_baf_internal_BStaticInvokeInst_H_
#define _JC_soot_baf_internal_BStaticInvokeInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BStaticInvokeInst$sub_refs	_jc_soot_baf_internal_BStaticInvokeInst$sub_refs;
typedef struct _jc_soot_baf_internal_BStaticInvokeInst$sub_nonrefs	_jc_soot_baf_internal_BStaticInvokeInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BStaticInvokeInst$refs	_jc_soot_baf_internal_BStaticInvokeInst$refs;
typedef struct _jc_soot_baf_internal_BStaticInvokeInst$nonrefs	_jc_soot_baf_internal_BStaticInvokeInst$nonrefs;
typedef struct _jc_soot_baf_internal_BStaticInvokeInst$object	_jc_soot_baf_internal_BStaticInvokeInst$object;

typedef const struct _jc_soot_baf_internal_BStaticInvokeInst$vmethods	_jc_soot_baf_internal_BStaticInvokeInst$vmethods;
typedef const struct _jc_soot_baf_internal_BStaticInvokeInst$vtable	_jc_soot_baf_internal_BStaticInvokeInst$vtable;
typedef const struct _jc_soot_baf_internal_BStaticInvokeInst$vtype	_jc_soot_baf_internal_BStaticInvokeInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BStaticInvokeInst$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *, struct _jc_soot_SootMethod$object *);

// Virtual methods
extern void _jc_soot_baf_internal_BStaticInvokeInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BStaticInvokeInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *);
extern jint _jc_soot_baf_internal_BStaticInvokeInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BStaticInvokeInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *);
extern jint _jc_soot_baf_internal_BStaticInvokeInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BStaticInvokeInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BStaticInvokeInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BStaticInvokeInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BStaticInvokeInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BStaticInvokeInst$method_info$getOutCount$de2aea04cd3e0d65;

// Virtual methods structure
struct _jc_soot_baf_internal_BStaticInvokeInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *);
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *);
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *);
};

// Vtable
struct _jc_soot_baf_internal_BStaticInvokeInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractInvokeInst$vmethods	soot_baf_internal_AbstractInvokeInst;
	_jc_soot_baf_internal_BStaticInvokeInst$vmethods	soot_baf_internal_BStaticInvokeInst;
};

// Vtype
struct _jc_soot_baf_internal_BStaticInvokeInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BStaticInvokeInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BStaticInvokeInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BStaticInvokeInst$refs {
    _jc_soot_baf_internal_BStaticInvokeInst$sub_refs	soot_baf_internal_BStaticInvokeInst;
    _jc_soot_baf_internal_AbstractInvokeInst$sub_refs	soot_baf_internal_AbstractInvokeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BStaticInvokeInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BStaticInvokeInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractInvokeInst$sub_nonrefs	soot_baf_internal_AbstractInvokeInst;
    _jc_soot_baf_internal_BStaticInvokeInst$sub_nonrefs	soot_baf_internal_BStaticInvokeInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BStaticInvokeInst$object {
	_jc_soot_baf_internal_BStaticInvokeInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BStaticInvokeInst$vtype	*vtype;
	_jc_soot_baf_internal_BStaticInvokeInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BStaticInvokeInst$vtype _jc_soot_baf_internal_BStaticInvokeInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BStaticInvokeInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BStaticInvokeInst$class_object;

#endif	/* _JC_soot_baf_internal_BStaticInvokeInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/BStaticInvokeInst.h <==
// public class soot.baf.internal.BStaticInvokeInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 9eae4bbac6711e7a soot_baf_internal_AbstractInvokeInst
// @dep_class e5868ea131204b74 soot_baf_internal_BStaticInvokeInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInvokeInst

#include "soot/baf/internal/AbstractInvokeInst.h"

#ifndef _JC_soot_baf_internal_BStaticInvokeInst_H_
#define _JC_soot_baf_internal_BStaticInvokeInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BStaticInvokeInst$sub_refs	_jc_soot_baf_internal_BStaticInvokeInst$sub_refs;
typedef struct _jc_soot_baf_internal_BStaticInvokeInst$sub_nonrefs	_jc_soot_baf_internal_BStaticInvokeInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BStaticInvokeInst$refs	_jc_soot_baf_internal_BStaticInvokeInst$refs;
typedef struct _jc_soot_baf_internal_BStaticInvokeInst$nonrefs	_jc_soot_baf_internal_BStaticInvokeInst$nonrefs;
typedef struct _jc_soot_baf_internal_BStaticInvokeInst$object	_jc_soot_baf_internal_BStaticInvokeInst$object;

typedef const struct _jc_soot_baf_internal_BStaticInvokeInst$vmethods	_jc_soot_baf_internal_BStaticInvokeInst$vmethods;
typedef const struct _jc_soot_baf_internal_BStaticInvokeInst$vtable	_jc_soot_baf_internal_BStaticInvokeInst$vtable;
typedef const struct _jc_soot_baf_internal_BStaticInvokeInst$vtype	_jc_soot_baf_internal_BStaticInvokeInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BStaticInvokeInst$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_internal_BStaticInvokeInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BStaticInvokeInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BStaticInvokeInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BStaticInvokeInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BStaticInvokeInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BStaticInvokeInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BStaticInvokeInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BStaticInvokeInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BStaticInvokeInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BStaticInvokeInst$method_info$getOutCount$de2aea04cd3e0d65;

// Virtual methods structure
struct _jc_soot_baf_internal_BStaticInvokeInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *) _JC_JCNI_ATTR;
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BStaticInvokeInst$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_BStaticInvokeInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractInvokeInst$vmethods	soot_baf_internal_AbstractInvokeInst;
	_jc_soot_baf_internal_BStaticInvokeInst$vmethods	soot_baf_internal_BStaticInvokeInst;
};

// Vtype
struct _jc_soot_baf_internal_BStaticInvokeInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BStaticInvokeInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BStaticInvokeInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BStaticInvokeInst$refs {
    _jc_soot_baf_internal_BStaticInvokeInst$sub_refs	soot_baf_internal_BStaticInvokeInst;
    _jc_soot_baf_internal_AbstractInvokeInst$sub_refs	soot_baf_internal_AbstractInvokeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BStaticInvokeInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BStaticInvokeInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractInvokeInst$sub_nonrefs	soot_baf_internal_AbstractInvokeInst;
    _jc_soot_baf_internal_BStaticInvokeInst$sub_nonrefs	soot_baf_internal_BStaticInvokeInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BStaticInvokeInst$object {
	_jc_soot_baf_internal_BStaticInvokeInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BStaticInvokeInst$vtype	*vtype;
	_jc_soot_baf_internal_BStaticInvokeInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BStaticInvokeInst$vtype _jc_soot_baf_internal_BStaticInvokeInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BStaticInvokeInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BStaticInvokeInst$class_object;

#endif	/* _JC_soot_baf_internal_BStaticInvokeInst_H_ */
